@@ -37,7 +37,6 @@
 #include "gui/stdactions.h"
 #include "mpd-interface/mpdstatus.h"
 #include "network/networkaccessmanager.h"
-#include "qtiocompressor/qtiocompressor.h"
 #include "support/action.h"
 #include "support/actioncollection.h"
 #include "support/utils.h"
@@ -53,6 +52,11 @@
 #include <QTimer>
 #include <QUrl>
 #include <QUrlQuery>
+#ifdef BUNDLED_KARCHIVE
+#include <kcompressiondevice.h>
+#else
+#include <KCompressionDevice>
+#endif
 
 const QLatin1String SongView::constLyricsDir("lyrics/");
 const QLatin1String SongView::constExtension(".lyrics");
@@ -439,12 +443,9 @@ void SongView::loadInfo()
 		QString prefix = engine->getPrefix(lang);
 		QString cachedFile = infoCacheFileName(currentSong, prefix, false);
 		if (QFile::exists(cachedFile)) {
-			QFile f(cachedFile);
-			QtIOCompressor compressor(&f);
-			compressor.setStreamFormat(QtIOCompressor::GzipFormat);
-			if (compressor.open(QIODevice::ReadOnly)) {
-				QByteArray data = compressor.readAll();
-
+			KCompressionDevice f(cachedFile, KCompressionDevice::GZip);
+			if (f.open(QIODevice::ReadOnly)) {
+			    QByteArray data = f.readAll();
 				if (!data.isEmpty()) {
 					infoSearchResponse(QString::fromUtf8(data), QString());
 					Utils::touchFile(cachedFile);
@@ -683,11 +684,9 @@ void SongView::infoSearchResponse(const QString& resp, const QString& lang)
 	if (!resp.isEmpty()) {
 		str = engine->translateLinks(resp);
 		if (!lang.isEmpty()) {
-			QFile f(infoCacheFileName(currentSong, lang, true));
-			QtIOCompressor compressor(&f);
-			compressor.setStreamFormat(QtIOCompressor::GzipFormat);
-			if (compressor.open(QIODevice::WriteOnly)) {
-				compressor.write(resp.toUtf8().constData());
+			KCompressionDevice f(infoCacheFileName(currentSong, lang, true), KCompressionDevice::GZip);
+			if (f.open(QIODevice::WriteOnly)) {
+			    f.write(resp.toUtf8().constData());
 			}
 		}
 	}
