@@ -31,7 +31,6 @@
 #include "musiclibraryitemartist.h"
 #include "musiclibraryitemsong.h"
 #include "musiclibrarymodel.h"
-#include "qtiocompressor/qtiocompressor.h"
 #include <QElapsedTimer>
 #include <QFile>
 #include <QXmlStreamReader>
@@ -40,6 +39,11 @@
 #ifdef TIME_XML_FILE_LOADING
 #include <QDebug>
 #endif
+#ifdef BUNDLED_KARCHIVE
+#include <kcompressiondevice.h>
+#else
+#include <KCompressionDevice>
+#endif
 
 MusicLibraryItemArtist* MusicLibraryItemRoot::artist(const Song& s, bool create)
 {
@@ -191,17 +195,17 @@ void MusicLibraryItemRoot::toXML(const QString& filename, MusicLibraryProgressMo
 		return;
 	}
 
-	QFile file(filename);
-	QtIOCompressor compressor(&file);
-	compressor.setStreamFormat(QtIOCompressor::GzipFormat);
-	if (!compressor.open(QIODevice::WriteOnly)) {
+
+	KCompressionDevice file(filename, KCompressionDevice::GZip);
+	if (!file.open(QIODevice::WriteOnly)) {
 		return;
 	}
 
-	QXmlStreamWriter writer(&compressor);
+	QXmlStreamWriter writer(&file);
 	toXML(writer, prog);
-	compressor.close();
-}
+	file.close();
+	}
+
 
 static const quint32 constVersion = 1;
 static const QString constTopTag = QLatin1String("tagcache");
@@ -352,20 +356,19 @@ bool MusicLibraryItemRoot::fromXML(const QString& filename, const QString& baseF
 	timer.start();
 #endif
 
-	QFile file(filename);
-	QtIOCompressor compressor(&file);
-	compressor.setStreamFormat(QtIOCompressor::GzipFormat);
-	if (!compressor.open(QIODevice::ReadOnly)) {
+	KCompressionDevice file(filename, KCompressionDevice::GZip);
+	if (!file.open(QIODevice::ReadOnly)) {
 		return false;
 	}
-	QXmlStreamReader reader(&compressor);
+	QXmlStreamReader reader(&file);
 	bool rv = fromXML(reader, baseFolder, prog, em);
-	compressor.close();
+	file.close();
 #ifdef TIME_XML_FILE_LOADING
 	qWarning() << filename << timer.elapsed();
 #endif
 	return rv;
-}
+	}
+
 
 bool MusicLibraryItemRoot::fromXML(QXmlStreamReader& reader, const QString& baseFolder, MusicLibraryProgressMonitor* prog, MusicLibraryErrorMonitor* em)
 {
