@@ -64,14 +64,6 @@ static QCache<QUrl, QImage> imageCache(200 * 1024);
 static int maxImageSize = -1;
 static const char* constOrigUrlProperty = "orig-url";
 
-enum Roles {
-	IsPodcastRole = Qt::UserRole,
-	UrlRole,
-	ImageUrlRole,
-	DescriptionRole,
-	WebPageUrlRole
-};
-
 QString PodcastSearchDialog::constCacheDir = QLatin1String("podcast-directories");
 QString PodcastSearchDialog::constExt = QLatin1String(".opml");
 
@@ -635,13 +627,15 @@ PodcastSearchDialog::PodcastSearchDialog(PodcastService* s, QWidget* parent)
 	pageWidget->addPage(urlPage, tr("Enter URL"), urlPage->icon(), tr("Manual podcast URL"));
 	pages << urlPage;
 
-	ITunesSearchPage* itunes = new ITunesSearchPage(pageWidget);
-	pageWidget->addPage(itunes, tr("Search %1").arg(itunes->name()), itunes->icon(), tr("Search for podcasts on %1").arg(itunes->name()));
-	pages << itunes;
-
-	GPodderSearchPage* gpodder = new GPodderSearchPage(pageWidget);
-	pageWidget->addPage(gpodder, tr("Search %1").arg(gpodder->name()), gpodder->icon(), tr("Search for podcasts on %1").arg(gpodder->name()));
-	pages << gpodder;
+	// Start hide service
+	//	ITunesSearchPage* itunes = new ITunesSearchPage(pageWidget);
+	//	pageWidget->addPage(itunes, tr("Search %1").arg(itunes->name()), itunes->icon(), tr("Search for podcasts on %1").arg(itunes->name()));
+	//	pages << itunes;
+	//
+	//	GPodderSearchPage* gpodder = new GPodderSearchPage(pageWidget);
+	//	pageWidget->addPage(gpodder, tr("Search %1").arg(gpodder->name()), gpodder->icon(), tr("Search for podcasts on %1").arg(gpodder->name()));
+	//	pages << gpodder;
+	// End hide service
 
 	QSet<QString> loaded;
 	pages << loadDirectories(Utils::dataDir(), false, loaded);
