@@ -24,9 +24,7 @@
 #include "itemview.h"
 #include "groupedview.h"
 #include "tableview.h"
-#ifdef ENABLE_CATEGORIZED_VIEW
 #include "categorizedview.h"
-#endif
 #include "actionitemdelegate.h"
 #include "basicitemdelegate.h"
 #include "config.h"
@@ -151,10 +149,8 @@ static int zoomedSize(QListView* view, int size)
 	return view
 			? qobject_cast<ListView*>(view)
 					? static_cast<ListView*>(view)->zoom() * size
-#ifdef ENABLE_CATEGORIZED_VIEW
 					: qobject_cast<CategorizedView*>(view)
 					? static_cast<CategorizedView*>(view)->zoom() * size
-#endif
 					: size
 			: size;
 }
@@ -164,10 +160,8 @@ static QSize zoomedSize(QListView* view, QSize size)
 	return view
 			? qobject_cast<ListView*>(view)
 					? static_cast<ListView*>(view)->zoom() * size
-#ifdef ENABLE_CATEGORIZED_VIEW
 					: qobject_cast<CategorizedView*>(view)
 					? static_cast<CategorizedView*>(view)->zoom() * size
-#endif
 					: size
 			: size;
 }
@@ -180,13 +174,8 @@ public:
 		  ,
 		  viewGap(Utils::scaleForDpi(8))
 #endif
-#ifdef ENABLE_CATEGORIZED_VIEW
 		  ,
 		  isCategorizedView(v && qobject_cast<CategorizedView*>(v))
-#else
-		  ,
-		  isCategorizedView(false)
-#endif
 	{
 	}
 
@@ -678,9 +667,7 @@ QString ItemView::modeStr(Mode m)
 	case Mode_IconTop: return QLatin1String("icontop");
 	case Mode_GroupedTree: return QLatin1String("grouped");
 	case Mode_Table: return QLatin1String("table");
-#ifdef ENABLE_CATEGORIZED_VIEW
 	case Mode_Categorized: return QLatin1String("categorized");
-#endif
 	}
 }
 
@@ -700,10 +687,8 @@ static const double constZoomStep = 0.25;
 
 ItemView::ItemView(QWidget* p)
 	: QWidget(p), searchTimer(nullptr), itemModel(nullptr), currentLevel(0), mode(Mode_SimpleTree), groupedView(nullptr), tableView(nullptr)
-#ifdef ENABLE_CATEGORIZED_VIEW
 	  ,
 	  categorizedView(nullptr)
-#endif
 	  ,
 	  spinner(nullptr), msgOverlay(nullptr), performedSearch(false), searchResetLevel(0), openFirstLevelAfterSearch(false), initialised(false), minSearchDebounce(250)
 {
@@ -849,7 +834,6 @@ void ItemView::allowTableView(TableView* v)
 
 void ItemView::allowCategorized()
 {
-#ifdef ENABLE_CATEGORIZED_VIEW
 	if (!categorizedView) {
 		categorizedView = new CategorizedView(stackedWidget);
 		categorizedView->setParent(stackedWidget);
@@ -868,7 +852,6 @@ void ItemView::allowCategorized()
 #endif
 		categorizedView->setItemDelegate(new ListDelegate(categorizedView, categorizedView));
 	}
-#endif
 }
 
 void ItemView::addAction(QAction* act)
@@ -881,11 +864,9 @@ void ItemView::addAction(QAction* act)
 	if (tableView) {
 		tableView->addAction(act);
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	if (categorizedView) {
 		categorizedView->addAction(act);
 	}
-#endif
 }
 
 void ItemView::addSeparator()
@@ -899,9 +880,7 @@ void ItemView::setMode(Mode m)
 {
 	initialised = true;
 	if (m < 0 || m >= Mode_Count || (Mode_GroupedTree == m && !groupedView) || (Mode_Table == m && !tableView)
-#ifdef ENABLE_CATEGORIZED_VIEW
 	    || (Mode_Categorized == m && !categorizedView)
-#endif
 	) {
 		m = Mode_SimpleTree;
 	}
@@ -933,11 +912,9 @@ void ItemView::setMode(Mode m)
 			tableView->saveHeader();
 			tableView->setModel(nullptr);
 		}
-#ifdef ENABLE_CATEGORIZED_VIEW
 		if (categorizedView) {
 			categorizedView->setModel(nullptr);
 		}
-#endif
 		treeView->setModel(itemModel);
 		treeView->setHidden(false);
 		static_cast<TreeDelegate*>(treeView->itemDelegate())->setSimple(Mode_SimpleTree == mode || Mode_BasicTree == mode);
@@ -954,11 +931,9 @@ void ItemView::setMode(Mode m)
 			tableView->saveHeader();
 			tableView->setModel(nullptr);
 		}
-#ifdef ENABLE_CATEGORIZED_VIEW
 		if (categorizedView) {
 			categorizedView->setModel(nullptr);
 		}
-#endif
 		groupedView->setHidden(false);
 		treeView->setHidden(true);
 		groupedView->setModel(itemModel);
@@ -974,11 +949,9 @@ void ItemView::setMode(Mode m)
 		if (groupedView) {
 			groupedView->setModel(nullptr);
 		}
-#ifdef ENABLE_CATEGORIZED_VIEW
 		if (categorizedView) {
 			categorizedView->setModel(nullptr);
 		}
-#endif
 		tableView->setHidden(false);
 		treeView->setHidden(true);
 		tableView->setModel(itemModel);
@@ -988,7 +961,6 @@ void ItemView::setMode(Mode m)
 		}
 		tableView->resize(w, tableView->height());
 		stackIndex = tableView->property(constPageProp).toInt();
-#ifdef ENABLE_CATEGORIZED_VIEW
 	}
 	else if (Mode_Categorized == mode) {
 		//int w=view()->width();
@@ -1005,7 +977,6 @@ void ItemView::setMode(Mode m)
 		categorizedView->setModel(itemModel);
 		stackIndex = categorizedView->property(constPageProp).toInt();
 		categorizedView->setGridSize(zoomedSize(listView, iconGridSize));
-#endif
 	}
 	else {
 		stackIndex = 1;
@@ -1017,11 +988,9 @@ void ItemView::setMode(Mode m)
 			tableView->saveHeader();
 			tableView->setModel(nullptr);
 		}
-#ifdef ENABLE_CATEGORIZED_VIEW
 		if (categorizedView) {
 			categorizedView->setModel(nullptr);
 		}
-#endif
 		listView->setModel(itemModel);
 		goToTop();
 		if (Mode_IconTop != mode) {
@@ -1064,11 +1033,9 @@ QModelIndexList ItemView::selectedIndexes(bool sorted) const
 	else if (Mode_Table == mode) {
 		return tableView->selectedIndexes(sorted);
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	else if (Mode_Categorized == mode) {
 		return categorizedView->selectedIndexes(sorted);
 	}
-#endif
 	return listView->selectedIndexes(sorted);
 }
 
@@ -1082,7 +1049,6 @@ void ItemView::goToTop()
 		}
 		listView->setRootIndex(QModelIndex());
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	else if (Mode_Categorized == mode) {
 		categorizedView->setRootIndex(QModelIndex());
 		categorizedView->setPlain(false);
@@ -1090,7 +1056,6 @@ void ItemView::goToTop()
 		// then items are all messed up!
 		categorizedView->setGridSizeOwn(categorizedView->gridSize());
 	}
-#endif
 	setTitle();
 	emit rootIndexSet(QModelIndex());
 }
@@ -1109,11 +1074,9 @@ void ItemView::setEnabled(bool en)
 	if (listView) {
 		listView->setEnabled(en);
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	if (categorizedView) {
 		categorizedView->setEnabled(en);
 	}
-#endif
 }
 
 void ItemView::setInfoText(const QString& info)
@@ -1126,11 +1089,9 @@ void ItemView::setInfoText(const QString& info)
 	if (tableView) {
 		tableView->setInfoText(info);
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	if (categorizedView) {
 		categorizedView->setInfoText(info);
 	}
-#endif
 }
 
 void ItemView::setLevel(int l, bool haveChildren)
@@ -1182,11 +1143,9 @@ QAbstractItemView* ItemView::view() const
 	else if (Mode_Table == mode) {
 		return tableView;
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	else if (Mode_Categorized == mode) {
 		return categorizedView;
 	}
-#endif
 	else {
 		return listView;
 	}
@@ -1255,11 +1214,9 @@ void ItemView::setAcceptDrops(bool v)
 	if (tableView) {
 		tableView->setAcceptDrops(v);
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	if (categorizedView) {
 		categorizedView->setAcceptDrops(v);
 	}
-#endif
 }
 
 void ItemView::setDragDropOverwriteMode(bool v)
@@ -1272,11 +1229,9 @@ void ItemView::setDragDropOverwriteMode(bool v)
 	if (tableView) {
 		tableView->setDragDropOverwriteMode(v);
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	if (categorizedView) {
 		categorizedView->setDragDropOverwriteMode(v);
 	}
-#endif
 }
 
 void ItemView::setDragDropMode(QAbstractItemView::DragDropMode v)
@@ -1289,11 +1244,9 @@ void ItemView::setDragDropMode(QAbstractItemView::DragDropMode v)
 	if (tableView) {
 		tableView->setDragDropMode(v);
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	if (categorizedView) {
 		categorizedView->setDragDropMode(v);
 	}
-#endif
 }
 
 void ItemView::update()
@@ -1331,7 +1284,6 @@ void ItemView::setDeleteAction(QAction* act)
 			static_cast<KeyEventHandler*>(tableView->filter())->setDeleteAction(act);
 		}
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	if (categorizedView) {
 		if (!categorizedView->filter() || !qobject_cast<KeyEventHandler*>(categorizedView->filter())) {
 			categorizedView->installEventFilter(new KeyEventHandler(categorizedView, act));
@@ -1340,7 +1292,6 @@ void ItemView::setDeleteAction(QAction* act)
 			static_cast<KeyEventHandler*>(categorizedView->filter())->setDeleteAction(act);
 		}
 	}
-#endif
 }
 
 void ItemView::showIndex(const QModelIndex& idx, bool scrollTo)
@@ -1356,11 +1307,9 @@ void ItemView::showIndex(const QModelIndex& idx, bool scrollTo)
 			v->scrollTo(idx, QAbstractItemView::PositionAtTop);
 		}
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	else if (Mode_Categorized == mode) {
 		// TODO
 	}
-#endif
 	else {
 		if (idx.parent().isValid()) {
 			QList<QModelIndex> indexes;
@@ -1504,11 +1453,9 @@ void ItemView::setBackgroundImage(const QIcon& icon)
 	else if (Mode_Table == mode && tableView) {
 		tableView->setBackgroundImage(bgndIcon);
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	else if (Mode_Categorized == mode && categorizedView) {
 		categorizedView->setBackgroundImage(bgndIcon);
 	}
-#endif
 	else if (Mode_List == mode || Mode_IconTop == mode) {
 		listView->setBackgroundImage(bgndIcon);
 	}
@@ -1623,7 +1570,6 @@ void ItemView::backActivated()
 		listView->setRootIndex(listView->rootIndex().parent());
 		emit rootIndexSet(listView->rootIndex().parent());
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	else {
 		categorizedView->setRootIndex(categorizedView->rootIndex().parent());
 		categorizedView->setPlain(false);
@@ -1632,7 +1578,6 @@ void ItemView::backActivated()
 		categorizedView->setGridSizeOwn(categorizedView->gridSize());
 		emit rootIndexSet(categorizedView->rootIndex().parent());
 	}
-#endif
 	setTitle();
 
 	if (prevTopIndex.isEmpty()) {
@@ -1651,11 +1596,9 @@ void ItemView::backActivated()
 			listView->scrollTo(prevTop, QAbstractItemView::PositionAtTop);
 		}
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	else {
 		categorizedView->scrollTo(prevTop, QAbstractItemView::PositionAtTop);
 	}
-#endif
 }
 
 void ItemView::setExpanded(const QModelIndex& idx, bool exp)
@@ -1668,9 +1611,7 @@ void ItemView::setExpanded(const QModelIndex& idx, bool exp)
 QAction* ItemView::getAction(const QModelIndex& index)
 {
 	QModelIndex idx =
-#ifdef ENABLE_CATEGORIZED_VIEW
 			Mode_Categorized == mode ? categorizedView->mapFromSource(index) :
-#endif
 									 index;
 	QAbstractItemDelegate* abs = view()->itemDelegate();
 	ActionItemDelegate* d = abs ? qobject_cast<ActionItemDelegate*>(abs) : nullptr;
@@ -1720,7 +1661,6 @@ void ItemView::activateItem(const QModelIndex& index, bool emitRootSet)
 		if (!index.parent().isValid()) {
 			tableView->setExpanded(index, !tableView->TreeView::isExpanded(index));
 		}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	}
 	else if (Mode_Categorized == mode) {
 		if (index == categorizedView->rootIndex()) {
@@ -1752,7 +1692,6 @@ void ItemView::activateItem(const QModelIndex& index, bool emitRootSet)
 			emit rootIndexSet(index);
 		}
 		categorizedView->scrollToTop();
-#endif
 	}
 	else if (usingListView() && (index.isValid() && (itemModel->index(0, 0, index).isValid() || itemModel->canFetchMore(index)) && index != listView->rootIndex())) {
 		if (itemModel->canFetchMore(index)) {
@@ -1806,11 +1745,9 @@ void ItemView::addTitleButtonClicked()
 	if ((Mode_List == mode || Mode_IconTop == mode) && view()->rootIndex().isValid()) {
 		emit updateToPlayQueue(view()->rootIndex(), false);
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	else if (Mode_Categorized == mode && categorizedView->rootIndex().isValid()) {
 		emit updateToPlayQueue(categorizedView->rootIndex(), false);
 	}
-#endif
 }
 
 void ItemView::replaceTitleButtonClicked()
@@ -1818,11 +1755,9 @@ void ItemView::replaceTitleButtonClicked()
 	if ((Mode_List == mode || Mode_IconTop == mode) && view()->rootIndex().isValid()) {
 		emit updateToPlayQueue(view()->rootIndex(), true);
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	else if (Mode_Categorized == mode && categorizedView->rootIndex().isValid()) {
 		emit updateToPlayQueue(categorizedView->rootIndex(), true);
 	}
-#endif
 }
 
 void ItemView::coverLoaded(const Song& song, int size)
@@ -1830,9 +1765,7 @@ void ItemView::coverLoaded(const Song& song, int size)
 	Q_UNUSED(song)
 
 	if (Mode_BasicTree == mode || Mode_GroupedTree == mode || !isVisible() || (Mode_IconTop == mode && size != zoomedSize(listView, gridCoverSize)) || (Mode_IconTop != mode && Mode_Categorized != mode && size != listCoverSize)
-#ifdef ENABLE_CATEGORIZED_VIEW
 	    || (Mode_Categorized == mode && size != zoomedSize(categorizedView, gridCoverSize))
-#endif
 	) {
 		return;
 	}
@@ -1847,14 +1780,12 @@ void ItemView::zoomIn()
 			listView->setGridSize(zoomedSize(listView, iconGridSize));
 		}
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	else if (categorizedView && categorizedView->isVisible()) {
 		if (categorizedView->zoom() + constZoomStep <= constMaxZoom) {
 			categorizedView->setZoom(categorizedView->zoom() + constZoomStep);
 			categorizedView->setGridSize(zoomedSize(categorizedView, iconGridSize));
 		}
 	}
-#endif
 }
 
 void ItemView::zoomOut()
@@ -1865,14 +1796,12 @@ void ItemView::zoomOut()
 			listView->setGridSize(zoomedSize(listView, iconGridSize));
 		}
 	}
-#ifdef ENABLE_CATEGORIZED_VIEW
 	else if (categorizedView && categorizedView->isVisible()) {
 		if (categorizedView->zoom() - constZoomStep >= constMinZoom) {
 			categorizedView->setZoom(categorizedView->zoom() - constZoomStep);
 			categorizedView->setGridSize(zoomedSize(categorizedView, iconGridSize));
 		}
 	}
-#endif
 }
 
 void ItemView::delaySearchItems()
